@@ -7,17 +7,13 @@ from http import HTTPStatus
 from typing import Union
 from urllib.parse import urljoin, urlencode
 
-import plogger
 import requests
+from plogger import logger
 from urllib3 import disable_warnings, exceptions
 
 disable_warnings(exceptions.InsecureRequestWarning)
 
 
-def json_data(data):
-    return json.dumps(data)
-
-
 def get_header_default(user_agent='ide', content_type='application/json-patch+json', accept='application/json'):
     return {
         'User-Agent': user_agent,
@@ -31,24 +27,30 @@ class RESTAssertion:
     """Parse requests response to get status code."""
 
     @staticmethod
-    def should_be_success_response_code(response):
+    def is_success(response) -> bool:
         """200 <= status_code < 400"""
-        assert response.ok, 'Response code is not success.'
+        return response.ok
 
     @staticmethod
-    def should_be_ok_response_code(response):
+    def is_ok(response) -> bool:
         """OK, 200. Request fulfilled, document follows"""
-        assert response.status_code == HTTPStatus.OK, 'Response code is not 200.'
+        return response.status_code == HTTPStatus.OK
 
     @staticmethod
-    def should_be_not_found_response_code(response):
-        """Nothing matches the given URI"""
-        assert response.status_code == HTTPStatus.NOT_FOUND, 'Response code is not 404.'
+    def is_not_found(response) -> bool:
+        """Nothing matches the given URI. 404"""
+
+        return response.status_code == HTTPStatus.NOT_FOUND
 
     @staticmethod
-    def should_be_bad_request(response):
-        """Bad request syntax or unsupported method"""
-        assert response.status_code == HTTPStatus.BAD_REQUEST, 'Response code is not 400.'
+    def is_bad_request(response) -> bool:
+        """Bad request syntax or unsupported method. 400"""
+        return response.status_code == HTTPStatus.BAD_REQUEST
+
+    @staticmethod
+    def is_unauthorized(response) -> bool:
+        """Bad request syntax or unsupported method. 401"""
+        return response.status_code == HTTPStatus.UNAUTHORIZED
 
 
 class RESTClient(RESTAssertion):
@@ -68,7 +70,7 @@ class RESTClient(RESTAssertion):
                  logger_enabled: bool = True):
 
         # Enable/disable logger
-        self.logger = plogger.logger(self.__class__.__name__, enabled=logger_enabled)
+        self.logger = logger(self.__class__.__name__, enabled=logger_enabled)
 
         # Credentials and settings for api url
         self.username = username
@@ -277,6 +279,8 @@ class RESTClient(RESTAssertion):
             self.logger.exception('Something wend wrong.')
             raise err
 
+        self.logger.info(f'[Response] {response.status_code}: "{response.text}"')
+
         return response
 
     @property
